@@ -6,23 +6,38 @@ GITHUB_DATE_FORMAT = "%Y/%m/%d %H:%M:%S"
 COMMIT_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S"
 
 
-
 def ghdate_to_datetime(github_date):
+    """Convert Github date string to Python datetime
+
+    :param str github_date: date string to parse
+    """
     date_without_tz = " ".join(github_date.strip().split()[:2])
     return datetime.strptime(date_without_tz, GITHUB_DATE_FORMAT)
 
 
 def datetime_to_ghdate(datetime_):
+    """Convert Python datetime to Github date string
+
+    :param str datetime_: datetime object to convert
+    """
     date_without_tz = datetime_.strftime(GITHUB_DATE_FORMAT)
     return " ".join([date_without_tz, GITHUB_TIMEZONE])
 
 
 def commitdate_to_datetime(commit_date):
+    """Convert commit date string to Python datetime
+
+    :param str github_date: date string to parse
+    """
     date_without_tz = commit_date[:-6]
     return datetime.strptime(date_without_tz, COMMIT_DATE_FORMAT)
 
 
 def datetime_to_commitdate(datetime_):
+    """Convert Python datetime to Github date string
+
+    :param str datetime_: datetime object to convert
+    """
     date_without_tz = datetime_.strftime(COMMIT_DATE_FORMAT)
     return "".join([date_without_tz, GITHUB_TIMEZONE])
 
@@ -52,7 +67,7 @@ class GithubCommand(object):
             # unicode keys are not accepted as kwargs by python, see:
             #http://mail-archives.apache.org/mod_mbox/qpid-dev/200609.mbox/%3C1159389941.4505.10.camel@localhost.localdomain%3E
             # So we make a local dict with the same keys but as strings:
-            return datatype(**dict((str(k), v) for (k,v) in value.iteritems()))
+            return datatype(**dict((str(k), v) for (k, v) in value.iteritems()))
         return value
 
     def get_values(self, *args, **kwargs):
@@ -61,24 +76,26 @@ class GithubCommand(object):
         if datatype:
             # Same as above, unicode keys will blow up in **args, so we need to
             # create a new 'values' dict with string keys
-            return [ datatype(**dict((str(k), v) for (k,v) in value.iteritems()))
-                     for value in values ]
+            return [datatype(**dict((str(k), v) for (k, v) in value.iteritems()))
+                    for value in values]
         else:
             return values
 
 
 def doc_generator(docstring, attributes):
+    """Utility function to augment BaseDataType docstring
+
+    :param str docstring: docstring to augment
+    :param dict attributes: attributes to add to docstring
+    """
     docstring = docstring or ""
-    def section(title):
-        return "\n".join([title, "-" * len(title)])
 
     def bullet(title, text):
-        return """    *``%s``*\n      %s\n""" % (title, text)
+        return """.. py:attribute:: %s\n\n   %s\n""" % (title, text)
 
-    a = section("Attributes")
     b = "\n".join([bullet(attr_name, attr.help)
-                    for attr_name, attr in attributes.items()])
-    return "\n".join([docstring, a, b])
+                   for attr_name, attr in attributes.items()])
+    return "\n\n".join([docstring, b])
 
 
 class Attribute(object):
@@ -157,7 +174,7 @@ class BaseDataType(type):
         #_contribute_method("__dict__", to_dict)
 
         def iterate(self):
-            not_empty = lambda e: e[1] is not None #AS I *think* this is what was intended.
+            not_empty = lambda e: e[1] is not None  # AS I *think* this is what was intended.
             return iter(filter(not_empty, vars(self).items()))
         _contribute_method("__iter__", iterate)
 
