@@ -10,6 +10,8 @@ class Repository(BaseData):
     fork = Attribute("If True, this is a fork of another repository.")
     owner = Attribute("Username of the user owning this repository.")
     homepage = Attribute("Homepage for this project.")
+    master_branch  = Attribute("Default branch, if set.")
+    integration_branch = Attribute("Integration branch, if set.")
     open_issues = Attribute("List of open issues for this repository.")
     created_at = DateAttribute("Datetime the repository was created.")
     pushed_at = DateAttribute("Datetime of the last push to this repository")
@@ -129,9 +131,6 @@ class Repositories(GithubCommand):
     def add_collaborator(self, project, username):
         """Adds an add_collaborator to a repo
 
-        Do not prefix repo_name with the user owning the repo like you do in
-        list_collaborators()
-
         :param str project: Github project
         :param str username: Github user to add as collaborator
         """
@@ -140,9 +139,6 @@ class Repositories(GithubCommand):
     def remove_collaborator(self, project, username):
         """Removes an add_collaborator from a repo
 
-        Do not prefix repo_name with the user owning the repo like you do in
-        list_collaborators()
-
         :param str project: Github project
         :param str username: Github user to add as collaborator
         """
